@@ -53,7 +53,7 @@ class TalosConsumer(object):
     consumerGroup = str
     messageProcessorFactory = MessageProcessorFactory
     messageReaderFactory = MessageReaderFactory
-    partitionFetcherMap = dict()
+    partitionFetcherMap = dict
     talosConsumerConfig = TalosClientConfig
     talosClientFactory = TalosClientFactory
     talosAdmin = TalosAdmin
@@ -110,6 +110,8 @@ class TalosConsumer(object):
                 GetDescribeInfoRequest(self.topicName))
         if fetcherMap:
             self.partitionFetcherMap = fetcherMap
+        else:
+            self.partitionFetcherMap = dict()
         if partitionCheckPoint:
             self.partitionCheckPoint = partitionCheckPoint
         else:
@@ -271,7 +273,8 @@ class TalosConsumer(object):
         # do not block the renew thread and switch thread to re-balance thread
         if renewResponse and len(renewResponse.failedPartitionList) > 0:
             failedRenewList = renewResponse.failedPartitionList
-            logger.error("The worker: " + self.workerId + " failed to renew partitions: " + str(failedRenewList))
+            logger.error("The worker: " + self.workerId + " failed to renew partitions: "
+                         + str(failedRenewList))
             self.release_partition_lock(failedRenewList)
 
         self.renewScheduleExecutor = Timer(interval=self.talosConsumerConfig
@@ -284,14 +287,11 @@ class TalosConsumer(object):
         topicName = Utils.get_topic_name_by_resource_name(
             str(topicTalosResourceName.topicTalosResourceName.topicTalosResourceName))
         response = self.talosAdmin.get_describe_info(GetDescribeInfoRequest(topicName))
+        resourceName = topicTalosResourceName.topicTalosResourceName.topicTalosResourceName
 
-        if not topicTalosResourceName.topicTalosResourceName.topicTalosResourceName ==\
-               response.topicTalosResourceName.topicTalosResourceName:
+        if not resourceName == response.topicTalosResourceName.topicTalosResourceName:
             logger.info("The consumer initialize failed by topic not found")
-            raise InvalidArgumentError("The topic: " + str(topicTalosResourceName.
-                                                           topicTalosResourceName.
-                                                           topicTalosResourceName) +
-                                       " not found")
+            raise InvalidArgumentError("The topic: " + resourceName + " not found")
 
         self.set_partition_number(response.partitionNumber)
         self.topicTalosResourceName = topicTalosResourceName.topicTalosResourceName
@@ -421,7 +421,7 @@ class TalosConsumer(object):
                 has = len(hasList)
 
                 # workerNum > partitionNum, idle workers have no match target, do nothing
-                if i > len(targetList):
+                if i >= len(targetList):
                     break
                 target = targetList[i]
                 if logger.isEnabledFor(logging.DEBUG):
@@ -474,6 +474,9 @@ class TalosConsumer(object):
                                                     workerId=self.workerId,
                                                     consumerClient=self.talosClientFactory.new_consumer_client(),
                                                     messageClient=self.talosClientFactory.new_message_client(),
+                                                    getPartitionOffsetClient=self.talosClientFactory.new_message_client(),
+                                                    queryPartitionCleint=self.talosClientFactory.new_consumer_client(),
+                                                    commitOffsetClient=self.talosClientFactory.new_consumer_client(),
                                                     messageProcessor=self.messageProcessorFactory.create_processor(),
                                                     messageReader=self.messageReaderFactory.create_message_reader(self.talosConsumerConfig),
                                                     outerCheckPoint=self.partitionCheckPoint.get(partitionId))
@@ -568,9 +571,14 @@ class TalosConsumer(object):
     # that avoid thread exit failed caused by rebalance partition when shutDownAllFetcher
     #
     def shutdown(self):
+        if not self.isActive:
+            logger.info("Worker: " + str(self.workerId) + " is already shutdown, "
+                        + "don't do it again.")
+            return
         logger.info("Worker: " + self.workerId + " is shutting down...")
         self.partitionScheduledExecutor.cancel()
         self.workerScheduleExecutor.cancel()
         self.shut_down_fetcher()
         self.renewScheduleExecutor.cancel()
+        self.isActive = False
         logger.info("Worker: " + self.workerId + " shutdown.")
