@@ -139,8 +139,8 @@ class PartitionSender:
                                                                     self.userMessageCallback)
                 self.messageCallbackExecutors.start()
                 if self.logger.isEnabledFor(logging.DEBUG):
-                    self.logger.debug("put " + messageList.size() +
-                                      " message success for partition: "
+                    self.logger.debug("put " + str(len(messageList))
+                                      + " message success for partition: "
                                       + str(self.partitionId))
         except Exception as e:
             # 1. backoff sleep and retry according to configuration
@@ -180,7 +180,7 @@ class PartitionSender:
             if self.logger.isEnabledFor(logging.DEBUG):
                 self.logger.warn("putMessage failed " + str(retry) +
                                  " times for partition: " + str(self.partitionId) +
-                                 ", sleep " + pauseTime +
+                                 ", sleep " + str(pauseTime) +
                                  "ms for avoid infinitely retry." + e.message)
             # 1. sleep
             Utils.sleep_pause_time(pauseTime)
